==> nextcloud-app-notes-4.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/lt_LT.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "Error" : "Klaida",
    "New note" : "Nauji užrašai",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
    "Deleted {title}" : "{title} ištrinti",
    "Undo Delete" : "Atšaukti ištrynimą",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "Settings" : "Nustatymai",
    "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
    "File extension for new notes" : "Naujų užrašų failo prievardis",
    "Display mode for notes" : "Užrašų rodinio veiksena",
    "Open in edit mode" : "Atverti redagavimo veiksenoje",
    "Open in preview mode" : "Atverti peržiūros veiksenoje",
    "No notes yet" : "Nėra užrašų",
    "Insert image" : "Įterpti paveikslą",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "Loading …" : "Įkeliama…",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Rename" : "Pervadinti",
    "Delete note" : "Ištrinti užrašus",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Use current version" : "Naudoti esamą versiją",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "Details" : "Išsamiau",
    "Edit" : "Taisyti",
    "Preview" : "Peržiūra",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Set category" : "Nustatyti kategoriją",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizuoti",
    "Click here to save manually" : "Spustelėkite čia norėdami įrašyti rankiniu būdu",
    "Saving failed!" : "Įrašymas nepavyko!",
    "Last modified: {date}" : "Paskutinis modifikavimas: {date}",
    "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
    "Subcategory" : "Subkategorija",
    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
    "Development Mode" : "Plėtotojo veiksena"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-notes-4.8.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/lt_LT.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "Reading notes from filesystem has failed." : "Nepavyko perskaityti užrašų iš failų sistemos.",
    "Error" : "Klaida",
    "New note" : "Nauji užrašai",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "Notes settings" : "Užrašų nustatymai",
    "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
    "Deleted {title}" : "{title} ištrinti",
    "Undo Delete" : "Atšaukti ištrynimą",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Ištrinti {number} užrašai","Ištrinti {number} užrašai","Ištrinta {number} užrašų","Ištrinti {number} užrašai"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Atkurti {number} užrašai","Atkurti {number} užrašai","Atkurta {number} užrašų","Atkurti {number} užrašai"],
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
    "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
    "File extension for new notes" : "Naujų užrašų failo prievardis",
    "Display mode for notes" : "Užrašų rodinio veiksena",
    "Action" : "Veiksmas",
    "User defined" : "Naudotojo apibrėžtas",
    "Open in edit mode" : "Atverti redagavimo veiksenoje",
    "Open in preview mode" : "Atverti peržiūros veiksenoje",
    "Insert link" : "Įterpti nuorodą",
    "Insert image" : "Įterpti paveikslą",
    "Switch between editor and viewer" : "Perjungti tarp redaktoriaus ir žiūryklės",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "No notes yet" : "Kol kas užrašų nėra",
    "Select an image" : "Pasirinkite paveikslą",
    "Wrong image" : "Neteisingas paveikslas",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Įsidiekite programėlę mobiliajame telefone, kad visur turėtumėte prieigą prie savo užrašų.",
    "Details" : "Išsamiau",
    "Delete note" : "Ištrinti užrašus",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Use version from server" : "Naudoti versiją iš serverio",
    "Use current version" : "Naudoti esamą versiją",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "Edit" : "Taisyti",
    "Preview" : "Peržiūra",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Error from Nextcloud server: {msg}" : "Klaida iš Nextcloud serverio: {msg}",
    "Loading …" : "Įkeliama…",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizuoti",
    "Set category" : "Nustatyti kategoriją",
    "Click here to save manually" : "Spustelėkite čia norėdami įrašyti rankiniu būdu",
    "Saving failed!" : "Įrašymas nepavyko!",
    "Last modified: {date}" : "Paskutinis modifikavimas: {date}",
    "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
    "Subcategory" : "Subkategorija",
    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
    "_%n character_::_%n characters_" : ["%n simbolis","%n simboliai","%n simbolių","%n simbolis"],
    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
    "Note not found." : "Užrašai nerasti.",
    "Note is locked." : "Užrašai užrakinti.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
    "Tasks" : "Užduotys",
    "Development Mode" : "Plėtotojo veiksena"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
